==> mpl_plotter-3.8.1.tar.gz: mpl_plotter-3.8.1/tests/presets/MYPRESET2D.py <==
preset = {
    ## Backend
    #"backend": "Qt5Agg",
    ## Fonts
    #"font": "serif",
    #"math_font": "dejavuserif",
    #"font_color": "black",
    ## Figure
    ## axes
    #"fig": None,
    #"ax": None,
    #"figsize": (6, 6),
    #"shape_and_position": 111,
    #"prune": None,
    #"resize_axes": False,
    #"aspect": None,
    ## Setup
    #"workspace_color": None,
    #"workspace_color2": None,
    #"background_color_figure": "white",
    #"background_color_plot": "white",
    #"background_alpha": 1,
    #"style": None,
    #"light": None,
    #"dark": None,
    ## Spines
    #"spine_color": None,
    #"spines_removed": (0, 0, 1, 1),
    ## Bounds
    #"x_upper_bound": None,
    #"x_lower_bound": None,
    #"y_upper_bound": None,
    #"y_lower_bound": None,
    #"x_bounds": None,
    #"y_bounds": None,
    ## Pads
    #"demo_pad_plot": True,
    #"x_upper_resize_pad": 0,
    #"x_lower_resize_pad": 0,
    #"y_upper_resize_pad": 0,
    #"y_lower_resize_pad": 0,
    ## Grid
    #"grid": True,
    #"grid_color": "lightgrey",
    #"grid_lines": "-.",
    ## Color
    #"color": "darkred",
    #"cmap": "RdBu_r",
    #"alpha": None,
    #"norm": None,
    ## Title
    #"title": None,
    #"title_size": 12,
    #"title_y": 1.025,
    #"title_weight": None,
    "title_font": "Pump Triline",
    "title_color": "pink",
    ## Labels
    #"x_label": None,
    #"x_label_size": 20,
    #"x_label_pad": 10,
    #"x_label_rotation": None,
    #"x_label_weight": None,
    #"y_label": None,
    #"y_label_size": 20,
    #"y_label_pad": 10,
    #"y_label_rotation": None,
    #"y_label_weight": None,
    ## Ticks
    #"x_tick_number": 3,
    #"x_tick_labels": None,
    #"y_tick_number": 3,
    #"y_tick_labels": None,
    #"x_label_coords": None,
    #"y_label_coords": None,
    #"tick_color": None,
    #"tick_label_pad": 5,
    #"ticks_where": (1, 1, 0, 0),
    ## Tick labels
    #"tick_label_size": None,
    #"x_tick_label_size": 15,
    #"y_tick_label_size": 15,
    #"x_custom_tick_locations": None,
    #"y_custom_tick_locations": None,
    #"fine_tick_locations": True,
    #"x_custom_tick_labels": None,
    #"y_custom_tick_labels": None,
    #"x_date_tick_labels": False,
    #"date_format": "%Y-%m-%d",
    #"tick_ndecimals": 1,
    #"x_tick_ndecimals": None,
    #"y_tick_ndecimals": 3,
    #"x_tick_rotation": None,
    #"y_tick_rotation": None,
    #"tick_labels_where": (1, 1, 0, 0),
    ## Color bar
    #"color_bar": False,
    #"cb_pad": 0.2,
    #"cb_axis_labelpad": 10,
    #"shrink": 0.75,
    #"extend": "neither",
    #"cb_title": None,
    #"cb_orientation": "vertical",
    #"cb_title_rotation": None,
    #"cb_title_style": "normal",
    #"cb_title_size": 10,
    #"cb_top_title_y": 1,
    #"cb_ytitle_labelpad": 10,
    #"cb_title_weight": "normal",
    #"cb_top_title": False,
    #"cb_y_title": False,
    #"cb_top_title_pad": None,
    #"x_cb_top_title": 0,
    #"cb_vmin": None,
    #"cb_vmax": None,
    #"cb_hard_bounds": False,
    #"cb_outline_width": None,
    #"cb_tick_number": 5,
    #"cb_ticklabelsize": 10,
    #"tick_ndecimals_cb": None,
    ## Legend
    #"plot_label": None,
    #"legend": False,
    #"legend_loc": "upper right",
    #"legend_bbox_to_anchor": None,
    #"legend_size": 15,
    #"legend_weight": "normal",
    #"legend_style": "normal",
    #"legend_handleheight": None,
    #"legend_ncol": 1,
    ## Subplots
    #"show": False,
    #"zorder": None,
    ## Save
    #"filename": None,
    #"dpi": None,
    ## Suppress output
    #"suppress": True,
}

==> mpl_plotter-3.8.5.tar.gz: mpl_plotter-3.8.5/tests/presets/MYPRESET2D.py <==
preset = {
    ## Backend
    #"backend": "Qt5Agg",
    ## Fonts
    #"font": "serif",
    #"math_font": "dejavuserif",
    #"font_color": "black",
    ## Figure
    ## axes
    #"fig": None,
    #"ax": None,
    #"figsize": (6, 6),
    #"shape_and_position": 111,
    #"prune": None,
    #"resize_axes": True,
    #"scale": None,
    #"aspect": 1,
    ## Setup
    #"workspace_color": None,
    #"workspace_color2": None,
    #"background_color_figure": "white",
    #"background_color_plot": "white",
    #"background_alpha": 1,
    #"style": None,
    #"light": None,
    #"dark": None,
    ## Spines
    #"spine_color": None,
    #"blend_edges": False,
    #"spines_removed": (0, 0, 1, 1),
    ## Bounds
    #"x_upper_bound": None,
    #"x_lower_bound": None,
    #"y_upper_bound": None,
    #"y_lower_bound": None,
    #"x_bounds": None,
    #"y_bounds": None,
    ## Pads
    #"demo_pad_plot": True,
    #"x_upper_resize_pad": 0,
    #"x_lower_resize_pad": 0,
    #"y_upper_resize_pad": 0,
    #"y_lower_resize_pad": 0,
    ## Grid
    #"grid": True,
    #"grid_color": "lightgrey",
    #"grid_lines": "-.",
    ## Color
    #"color": "darkred",
    #"cmap": "RdBu_r",
    #"alpha": None,
    #"norm": None,
    ## Title
    #"title": None,
    "title_size": 100,
    #"title_y": 1.025,
    #"title_weight": None,
    "title_font": "Pump Triline",
    "title_color": "pink",
    ## Labels
    #"x_label": None,
    #"x_label_size": 20,
    #"x_label_pad": 10,
    #"x_label_rotation": None,
    #"x_label_weight": None,
    #"y_label": None,
    #"y_label_size": 20,
    #"y_label_pad": 10,
    #"y_label_rotation": None,
    #"y_label_weight": None,
    ## Ticks
    #"x_tick_number": 3,
    #"x_tick_labels": None,
    #"y_tick_number": 3,
    #"y_tick_labels": None,
    #"x_label_coords": None,
    #"y_label_coords": None,
    #"tick_color": None,
    #"tick_label_pad": 5,
    #"ticks_where": (1, 1, 0, 0),
    ## Tick labels
    #"tick_label_size": None,
    #"x_tick_label_size": 15,
    #"y_tick_label_size": 15,
    #"x_custom_tick_locations": None,
    #"y_custom_tick_locations": None,
    #"fine_tick_locations": True,
    #"x_custom_tick_labels": None,
    #"y_custom_tick_labels": None,
    #"x_date_tick_labels": False,
    #"date_format": "%Y-%m-%d",
    #"tick_ndecimals": 1,
    #"x_tick_ndecimals": None,
    #"y_tick_ndecimals": 3,
    #"x_tick_rotation": None,
    #"y_tick_rotation": None,
    #"tick_labels_where": (1, 1, 0, 0),
    ## Color bar
    #"color_bar": False,
    #"cb_pad": 0.2,
    #"cb_axis_labelpad": 10,
    #"shrink": 0.75,
    #"extend": "neither",
    #"cb_title": None,
    #"cb_orientation": "vertical",
    #"cb_title_rotation": None,
    #"cb_title_style": "normal",
    #"cb_title_size": 10,
    #"cb_top_title_y": 1,
    #"cb_ytitle_labelpad": 10,
    #"cb_title_weight": "normal",
    #"cb_top_title": False,
    #"cb_y_title": False,
    #"cb_top_title_pad": None,
    #"x_cb_top_title": 0,
    #"cb_vmin": None,
    #"cb_vmax": None,
    #"cb_hard_bounds": False,
    #"cb_outline_width": None,
    #"cb_tick_number": 5,
    #"cb_ticklabelsize": 10,
    #"tick_ndecimals_cb": None,
    ## Legend
    #"plot_label": None,
    #"legend": False,
    #"legend_loc": "upper right",
    #"legend_bbox_to_anchor": None,
    #"legend_size": 15,
    #"legend_weight": "normal",
    #"legend_style": "normal",
    #"legend_handleheight": None,
    #"legend_ncol": 1,
    ## Subplots
    #"show": False,
    #"zorder": None,
    ## Save
    #"filename": None,
    #"dpi": None,
    ## Suppress output
    #"suppress": True,
}
